summaryrefslogtreecommitdiffstats
path: root/content
diff options
context:
space:
mode:
authormirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-04 16:08:52 +0000
committermirandac@chromium.org <mirandac@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-04-04 16:08:52 +0000
commit81bb1092f354f3cb3c597ab3c9ed568905078e49 (patch)
tree7e8c5f324f49fc7302e6f1ee742c39169340e03f /content
parent96dcc176c46003af0176f0f4772affc741aa772a (diff)
downloadchromium_src-81bb1092f354f3cb3c597ab3c9ed568905078e49.zip
chromium_src-81bb1092f354f3cb3c597ab3c9ed568905078e49.tar.gz
chromium_src-81bb1092f354f3cb3c597ab3c9ed568905078e49.tar.bz2
Detach the PromoResourceService and WebResourceService from the Profile; have them store web resource data in local state instead.
We don't need multiple services for different Profiles; instead, there is a single service that captures data in local_state. The only preference stored in the Profile about the promo will be a bool indicating whether it's been closed or not, which will now be set outside the service. Reviewers: arv for general changes to PromoResourceService, & unittest. erg for pulling the service out of the Profile and serving it up as a Singleton. zmo for the changes I made to gpu_data_manager. jstritar FYI, for changes to the PromoResourceService. BUG=77155 TEST=promo resource service unittests. Review URL: http://codereview.chromium.org/6736028 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@80318 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content')
-rw-r--r--content/common/notification_type.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/content/common/notification_type.h b/content/common/notification_type.h
index b7d7fd2..9e86608 100644
--- a/content/common/notification_type.h
+++ b/content/common/notification_type.h
@@ -786,11 +786,15 @@ class NotificationType {
// should be the UI thread.
DEFAULT_REQUEST_CONTEXT_AVAILABLE,
// The state of a web resource has been changed. A resource may have been
// added, removed, or altered. Source is WebResourceService, and the
// details are NoDetails.
PROMO_RESOURCE_STATE_CHANGED,
+ // The user has elected not to display the promo on the New Tab Page.
+ // Source is WebResourceService, and the details are NoDetails.
+ PROMO_CLOSED,
+
// Autocomplete ------------------------------------------------------------
// Sent by the autocomplete controller when done. The source is the
@@ -786,11 +786,15 @@ class NotificationType {
// should be the UI thread.
DEFAULT_REQUEST_CONTEXT_AVAILABLE,
- // The state of a web resource has been changed. A resource may have been
+ // The state of a promo resource has been changed. A resource may have been
// added, removed, or altered. Source is WebResourceService, and the
// details are NoDetails.